package ru.crystals.test.plugins;

import org.junit.Before;
import org.junit.Test;
import org.mockito.internal.util.reflection.Whitebox;
import org.slf4j.helpers.NOPLogger;
import ru.crystals.pos.api.plugin.card.BonusOperationResponse;
import ru.crystals.pos.api.plugin.card.BonusOperationStatus;
import ru.crystals.pos.api.plugin.card.BonusWriteOffOperationResponse;
import ru.crystals.pos.api.plugin.card.CardInfo;
import ru.crystals.pos.api.plugin.card.CardSearchResponse;
import ru.crystals.pos.api.plugin.card.CardSearchResponseStatus;
import ru.crystals.pos.spi.IntegrationProperties;
import ru.crystals.pos.spi.receipt.CardStatus;
import ru.crystals.pos.spi.receipt.CardType;

import java.math.BigDecimal;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public class TestCardPluginTest extends BaseTest {

    private TestCardPlugin plugin;

    @Before
    public void beforeTest() {
        IntegrationProperties ips = mockIntegrationProperties();
        plugin = new TestCardPlugin();
        Whitebox.setInternalState(plugin, "integrationProperties", ips);
        Whitebox.setInternalState(plugin, "logger", NOPLogger.NOP_LOGGER);
        plugin.init();
    }

    @Test
    public void testSearchCard() {
        CardSearchResponse response = plugin.searchCard(null);
        assertNotNull(response);
        assertEquals(CardSearchResponseStatus.OK, response.getResponseStatus());
        assertEquals(1, response.getCashierMessages().size());
        assertEquals("Message", response.getCashierMessages().get(0));
        assertNotNull(response.getCard());
        assertEquals("385281233", response.getCard().getCardNumber());
        assertEquals("aideeeee", response.getCard().getId());
        assertEquals(CardType.EXTERNAL, response.getCard().getCardType());
        assertEquals(CardStatus.ACTIVE, response.getCard().getCardStatus());
        assertEquals(2, response.getCard().getExtendedAttributes().size());
        assertEquals("val", response.getCard().getExtendedAttributes().get("attr"));
        assertEquals("", response.getCard().getExtendedAttributes().get("attr2"));
        assertNotNull(response.getCard().getBonusBalance());
        assertEquals(BigDecimal.valueOf(4260, 2), response.getCard().getBonusBalance().getBalance());
        assertEquals(BigDecimal.valueOf(20, 2), response.getCard().getBonusBalance().getSumToChargeOff());
        assertEquals(BigDecimal.valueOf(325, 2), response.getCard().getBonusBalance().getSumAllowedToChargeOff());
    }

    @Test
    public void testCardInfo() {
        CardInfo cardInfo = plugin.getCardInfo(null);
        assertNotNull(cardInfo);
        assertEquals(CardSearchResponseStatus.OK, cardInfo.getCardSearchStatus());
        assertEquals("Card Info Title", cardInfo.getTitle());
        assertEquals(2, cardInfo.getInfo().size());
        assertEquals("123456", cardInfo.getInfo().get("Number"));
        assertEquals("Active", cardInfo.getInfo().get("Status"));
    }

    @Test
    public void testWriteoff() {
        BonusWriteOffOperationResponse response = plugin.writeOff(null, null, null);
        assertNotNull(response);
        assertEquals(BonusOperationStatus.TRY_AGAIN, response.getResponseStatus());
        assertEquals("8765", response.getTxId());
        assertEquals("Message to cashier", response.getOperatorMessage());
        assertEquals(2, response.getCardExtendedAttributesMap().size());
        assertEquals("card-value1", response.getCardExtendedAttributesMap().get("card-key1"));
        assertEquals("card-value2", response.getCardExtendedAttributesMap().get("card-key2"));
        assertEquals(2, response.getReceiptExtendedAttributesMap().size());
        assertEquals("receipt-value1", response.getReceiptExtendedAttributesMap().get("receipt-key1"));
        assertEquals("receipt-value2", response.getReceiptExtendedAttributesMap().get("receipt-key2"));
    }

    @Test
    public void testRollback() {
        BonusOperationResponse response = plugin.rollback("tx-id");
        assertNotNull(response);
        assertEquals(BonusOperationStatus.OK, response.getResponseStatus());
        assertEquals("645", response.getTxId());
    }
}
