package ru.crystals.pos.api.plugin;

import ru.crystals.pos.api.plugin.payment.PaymentToRefundReplacement;
import ru.crystals.pos.spi.plugin.payment.RefundRequest;
import ru.crystals.pos.spi.plugin.payment.TransactionalRefundRequest;

/**
 * Интерфейс, расширяющий возможности возврата транзакций из чека продажи
 * <p>
 * В частности поддерживает объединение нескольких транзакций для возврата за одну операцию (cм. {@link PaymentToRefundReplacement#getUsedFor()})
 * <p>
 * При реализации плагином этого интерфейса, касса будет вызывать {@link #doTransactionalRefund(TransactionalRefundRequest)} для возврата
 * транзакций из чека продажи (как отдельных, так и объединенных), а {@link PaymentPlugin#doRefund(RefundRequest)} для произвольного возврата.
 * <p>
 * Должен быть реализован в дополнение к {@link PaymentPlugin}.
 *
 * @since 1.5.0
 */
public interface TransactionalRefundPlugin {

    /**
     * Запрос на возврат одной или нескольких транзакций оплаты
     * <p>
     * Касса вызывает этот метод после подтверждения суммы возврата кассиром (сумма не редактируется) по выбранной транзакции для возврата.
     * <p>
     * Важно! Форма ввода суммы для возврата не должна выводиться плагином при вызове этого метода.
     * <p>
     * Касса ожидает, что в результате успешного выполнения будут возвращены все транзакции {@link TransactionalRefundRequest#getPaymentsToRefund()}
     * на соответствующие суммы и общая сумма возврата в точности совпадает с {@link TransactionalRefundRequest#getSumToRefund()}.
     * <p>
     * Результат выполнения/не выполнения возвращается в кассу через обратные вызовы {@link TransactionalRefundRequest#getOperationCallback()}
     *
     * @param refundRequest данные запроса на проведение возврата транзакции/транзакций оплаты
     */
    void doTransactionalRefund(TransactionalRefundRequest refundRequest);

}
