package ru.crystals.pos.api.plugin.payment;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/**
 * Данные о совершенной платежной операции, которые должны быть использованы кассой для печати и сохранения в БД
 *
 * @since 1.5.0
 */
public class PaymentResultData {

    /**
     * Данные транзакции выполненной оплаты для сохранения в БД &lt;ключ, значение&gt;
     */
    private Map<String, String> data = new HashMap<>();

    /**
     * Слипы для печати
     */
    private List<String> slips;

    /**
     * Дополнительные данные в формате &lt;ключ, значение&gt;, которые будут добавлены в чек
     */
    private Map<String, String> extendedReceiptAttributes = new HashMap<>();

    /**
     * Данные транзакции выполненной оплаты для сохранения в БД {@code<ключ, значение>}
     *
     * @return коллекция ключей и значений
     */
    public Map<String, String> getData() {
        return data;
    }

    /**
     * Получить значение поля по ключу из сохраненной в БД транзакции.
     *
     * @param key ключ, по которому ищется значение
     * @return значение поля или null, если значение отсутствует
     * @see #getData()
     */
    public String getData(String key) {
        return data.get(key);
    }

    /**
     * Слипы для печати
     *
     * @return slips слипы
     */
    public List<String> getSlips() {
        if (slips == null) {
            slips = new LinkedList<>();
        }
        return slips;
    }

    /**
     * Слипы для печати
     *
     * @param slips слипы
     */
    public void setSlips(List<String> slips) {
        this.slips = slips;
    }

    /**
     * Дополнительные данные в формате &lt;ключ, значение&gt;, которые будут добавлены в чек
     *
     * @return коллекция ключей и значений
     */
    public Map<String, String> getExtendedReceiptAttributes() {
        return extendedReceiptAttributes;
    }

    @Override
    public String toString() {
        return "PaymentResult{" +
               ", data=" + data +
               ", slips=" + slips +
               ", extendedReceiptAttributes=" + extendedReceiptAttributes +
               '}';
    }
}
