package ru.crystals.pos.api.plugin.techprocess;

import java.util.Collections;
import java.util.Optional;
import java.util.Set;

import ru.crystals.pos.spi.receipt.Merchandise;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Описывает контекст передачи управления плагину.
 */
public interface InterceptionContext {

    /**
     * @return часть тех. процесса, в которой произошла передача управления плагину
     */
    InterceptedStage getInterceptedStage();

    /**
     * @return текущий чек, если есть и доступен
     */
    default Optional<Receipt> getReceipt() {
        return Optional.empty();
    }

    /**
     * В общем случае сценарий поддерживает разное множество допустимых статусов прерывания.
     * Обязательным доступным статусом является {@link InterceptionStatus#CONTINUE}.
     *
     * @return множество допустимых статусов
     */
    default Set<InterceptionStatus> getApplicableStatusSet() {
        return Collections.singleton(InterceptionStatus.CONTINUE);
    }

    /**
     * @return текущий товар (доступен только при {@link InterceptedStage#PRODUCT_FOUND_FOR_SALE}).
     */
    default Optional<Merchandise> getMerchandise() {
        return Optional.empty();
    }

}
