package ru.crystals.pos.api.plugin.user;

import java.util.Set;

/**
 * Структура, описывающая данные о кассире.
 */
public class User {

    /**
     * Табельный номер
     */
    private String tabNumber;

    /**
     * Имя
     */
    private String firstName;
    /**
     * Отчество
     */
    private String middleName;
    /**
     * Фамилия
     */
    private String lastName;
    
    /**
     * Должность
     */
    private String roleName;

    /**
     * Массив всех разрешённых прав кассира
     */
    private Set<UserRight> userRights;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link User}
     */
    public User() {
        //
    }

    /**
     * Возвращает табельный номер кассира.
     * @return табельный номер кассира.
     */
    public String getTabNumber() {
        return tabNumber;
    }

    /**
     * Устанавливает табельный номер кассира.
     * @param tabNumber табельный номер кассира.
     */
    public void setTabNumber(String tabNumber) {
        this.tabNumber = tabNumber;
    }

    /**
     * Возвращает имя кассира.
     * @return имя кассира.
     */
    public String getFirstName() {
        return firstName;
    }

    /**
     * Устанавливает имя кассира.
     * @param firstName имя кассира.
     */
    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    /**
     * Возвращает отчество кассира.
     * @return отчество кассира.
     */
    public String getMiddleName() {
        return middleName;
    }

    /**
     * Устанавливает отчество кассира.
     * @param middleName отчество кассира.
     */
    public void setMiddleName(String middleName) {
        this.middleName = middleName;
    }

    /**
     * Возвращает фамилию кассира.
     * @return фамилия кассира.
     */
    public String getLastName() {
        return lastName;
    }

    /**
     * Устанавливает фамилию кассира.
     * @param lastName фамилия кассира.
     */
    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    /**
     * Возвращает должность кассира.
     * @return должность кассира.
     */
    public String getRoleName() {
        return roleName;
    }

    /**
     * Устанавливает должность кассира.
     * @param roleName должность кассира.
     */
    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }

    /**
     * Возвращает привилегии кассира
     *
     * @return массив доступных привилегий кассира
     */
    public Set<UserRight> getUserRights() {
        return userRights;
    }

    /**
     * Установить привилегии кассиру
     *
     * @param userRights массив доступных привилегий кассира
     */
    public void setUserRights(Set<UserRight> userRights) {
        this.userRights = userRights;
    }

    @Override
    public String toString() {
        return "User{" +
                "tabNumber='" + tabNumber + '\'' +
                ", firstName='" + firstName + '\'' +
                ", middleName='" + middleName + '\'' +
                ", lastName='" + lastName + '\'' +
                ", roleName='" + roleName + '\'' +
                ", userRightSet '" + userRights + '\'' +
                '}';
    }
}
