package ru.crystals.pos.spi.plugin.payment;

import ru.crystals.pos.spi.receipt.Receipt;

import java.util.List;

/**
 * Данные запроса на подготовку к возврату
 *
 * @since 1.5.0
 */
public interface RefundPreparationRequest {
    /**
     * Текущий чек возврата
     *
     * @return чек возврата
     */
    Receipt getRefundReceipt();

    /**
     * Список транзакций чека продажи, доступных для возврата.
     * <p>
     * Сумма доступная для возврата ({@link PaymentToRefund#getSumToRefund()}) рассчитывается до объединения в этом списке означает максимально возможную  полную сумму. в этом запросе не учитывает сумму
     * <p>
     * В текущей реализации содержит только транзакции, принадлежащие к тому же самому плагину
     *
     * @return список транзакций, доступных для возврата
     */
    List<PaymentToRefund> getPaymentsToRefund();

    /**
     * Чек продажи, возврат которого сейчас выполняется
     *
     * @return чек продажи, не может быть null, поскольку {@link RefundPreparationRequest} используется только при возврате по чеку
     */
    Receipt getOriginalReceipt();

}
