package ru.crystals.pos.spi.receipt;

/**
 * Перечисление типов карт
 *
 */
public enum CardType {
    /**
     * Внутренняя (дисконтная) карта: карта, заведенная в системе SET10
     */
    INTERNAL,

    /**
     * Внешняя карта: дисконтная карта внешней [по отношению к SET10] системы лояльности
     */
    EXTERNAL,

    /**
     * Внешняя карта, данные для формирования которой могут быть получены из нескольких систем/процессингов/плагинов
     * (на данный момент максимум 2х). Если плагином карт кассе передан данный тип, касса повторит поиск по всем процессингам,
     * кроме вызвавшего данный механизм, и в случае если новые данные будут найдены, дополнит ими исходный результат.
     * В качестве ID процессинга итоговой карты будет использован переданный явным образом CardEntity#processingId.
     * Если таковой не передан, в качестве ID процессинга будет использован ID процессинга из дополняющих данных.
     */
    MULTI_PROCESSING,

    /**
     * Подарочная карта
     */
    GIFT,

    /**
     * Бонусная карта
     * @deprecated тип считается устаревшим и не рекомендуется к использованию. Используйте {@link CardType#EXTERNAL}
     */
    @Deprecated
    BONUS,

    /**
     * Купон
     */
    COUPON;
}
