package ru.crystals.pos.spi.ui;

/**
 * Модель данных для произвольного сообщения на кассе.
 */
public class MessageParameters {

    private String text;

    private MessageQueue.ScheduledMoment scheduledMoment;

    /**
     * Признак, что сообщение кассиру может быть автоматически закрыто сканированием ШК или MSR.
     * Если сообщений несколько, одним сканированием закрываются все.
     * Если хоть одно из сообщений нельзя пропускать, не будут закрыты и остальные.
     * @since 0.0.88
     */
    private boolean autoCloseable;

    /**
     * Конструктор.
     *
     * @param text текст сообщения
     * @param scheduledMoment планируемый момент отображения сообщения
     */
    public MessageParameters(String text, MessageQueue.ScheduledMoment scheduledMoment) {
        this.text = text;
        this.scheduledMoment = scheduledMoment;

    }

    /**
     * Получить текст сообщения
     *
     * @return текст
     */
    public String getText() {
        return text;
    }

    /**
     * Установить текст сообщения
     *
     * @param text текст
     */
    public void setText(String text) {
        this.text = text;
    }

    /**
     * Получить планируемый момент отображения сообщения.
     *
     * @return момент отображения
     */
    public MessageQueue.ScheduledMoment getScheduledMoment() {
        return scheduledMoment;
    }

    /**
     * Установить планируемый момент отображения сообщения.
     *
     * @param scheduledMoment момент отображения
     */
    public void setScheduledMoment(MessageQueue.ScheduledMoment scheduledMoment) {
        this.scheduledMoment = scheduledMoment;
    }

    public boolean isAutoCloseable() {
        return autoCloseable;
    }

    public void setAutoCloseable(boolean autoCloseable) {
        this.autoCloseable = autoCloseable;
    }

    @Override
    public String toString() {
        return "MessageParameters{" +
                "text='" + text + '\'' +
                ", moment='" + scheduledMoment.toString() + '\'' +
                ", autoCloseable='" + autoCloseable + '\'' +
                '}';
    }

}
