package ru.crystals.pos.spi.ui;

/**
 * Описание действия на форме с таблицей, поддерживающей выбор строк.
 *
 * Имеются как стандартные действия, например {@link TableSelectionFormAction#ACTION_CLICK}, так и дополнительные.
 * Задание дополнительного действия приводит к добавлению кнопки на форме.
 */
public class TableSelectionFormAction {

    /**
     * Нажатие на строку.
     *
     * На touch-кассе - это нажатие на строку.
     * На POS-кассе - это нажатие добавленной кнопки.
     */
    public static final String ACTION_CLICK = "clickAction";

    /**
     * Выбор строки.
     *
     * На touch-кассе - это нажатие на чекбокс.
     * На POS-кассе - это нажатие добавленной кнопки.
     */
    public static final String ACTION_SELECTION = "selectionAction";

    /**
     * Отмена (закрытие формы).
     *
     * На touch-кассе - это нажатие на кнопку "отменить"
     * На POS-кассе - это нажатие клавиши Esc.
     */
    public static final String ACTION_CANCEL = "cancelAction";

    /**
     * Идентификатор действия.
     */
    private final String id;

    /**
     * Текст кнопки, если для действия добавляется кнопка.
     */
    private final String text;

    /**
     * Текст кнопки, если для действия добавляется кнопка и текущая строка не выбрана (только для POS-кассы).
     */
    private final String unselectedText;

    /**
     * Конструктор.
     *
     * @param id   идентификатор действия
     * @param text отображаемый текст кнопки в случае, если для данного действия добавляется кнопка
     */
    public TableSelectionFormAction(String id, String text) {
        this(id, text, null);
    }

    /**
     * Конструктор.
     *
     * @param id             идентификатор действия
     * @param text           отображаемый текст кнопки в случае, если для данного действия добавляется кнопка
     * @param unselectedText отображаемый текст кнопки в случае, если для данного действия добавляется кнопка
     *                       и текущая строка не выбрана (только для POS-кассы)
     */
    public TableSelectionFormAction(String id, String text, String unselectedText) {
        this.id = id;
        this.text = text;
        this.unselectedText = unselectedText;
    }

    public String getId() {
        return id;
    }

    public String getText() {
        return text;
    }

    public String getUnselectedText() {
        return unselectedText;
    }
}
